@@ -1,6 +1,7 @@
 use thiserror::Error;
 
 #[derive(Debug, Error)]
+/// Possible errors in the request-response lifecycle.
 pub enum Error {
     #[error("Reqwest error: {0}")]
     Reqwest(#[from] reqwest::Error),
@@ -11,6 +12,9 @@ pub enum Error {
         msg: String,
     },
 
+    #[error("Pagination error: {msg}")]
+    Pagination { msg: String },
+
     #[error("Invalid request. Received status {0}. Message: {1}")]
     ClientError(reqwest::StatusCode, String),
 
